/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2008 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp08nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp08nid ;

DATA library.&dataset ;
INFILE datafile LRECL=2033;
INPUT
   DISGORGE  1-3            BUSTEXT $ 4-41           OWNSTEXT $ 42-60      
   FINSTXT $ 61-94          FINDOTXT $ 95-104        OFENTXT1 $ 105        
   OFENTXT2 $ 106           OFENTXT3 $ 107           PRMONTXT $ 108-144    
   ORDERTXT $ 145-243       TYPEOTTX $ 244-305       CPIDN  306-312        
   PSR  313                 JANDC  314               PLEA  315-316         
   REASONS  317             INDICT  318              SENTRANS  319         
   WRKSHT  320              INCORPYR  321-324        INCORLOC  325         
   ORGTYPE  326             BUSCLAS  327-330         FTEMNUM  331-334      
   FTEMSIGN  335            SELFREP  336             HSMISCND  337         
   PRCRIME  338             PRCIVIL  339             OWNSTRCT  340         
   FINSTDS  341             FINSTDO  342             OFFENSE1  343-344     
   OFFENSE2  345            OFFENSE3  346            PRIMOFF  347-348      
   NOCOUNTS  349-350        SOURCES  351             OFFLVL  352-353       
   DETBFINE  354            TOLERNCE  355            HISTORY  356          
   VIOLATE  357             OBSTRUCT  358            COMPLY  359           
   ACCEPT  360-361          CCULPSCO  362-363        FCULPSCO  364-365     
   MINFINML  366-369        MAXFINML  370-372        DISPOSIT  373         
   PROBATN  374-375         COFI  376                PROBMON  377          
   ORDERCE  378             TYPEOTHS  379-380        CRIMPURP  381         
   CANTPAY  382             ADJOFL1  383-384         ADJOFL2  385-386      
   ADJOFLHI  387-388        ADJ_B1  389-390          ADJ_B2  391           
   ADJ_BHI  392-393         ADJ_C1  394-395          ADJ_C2  396           
   ADJ_CHI  397-398         ADJ_D1  399-401          ADJ_D2  402           
   ADJ_DHI  403-405         ADJ_E1  406              ADJ_E2  407           
   ADJ_EHI  408             ADJ_F1  409              ADJ_F2  410           
   ADJ_FHI  411             ADJ_G1  412              ADJ_G2  413           
   ADJ_GHI  414             ADJ_H1  415              ADJ_H2  416           
   ADJ_HHI  417             ADJ_I1  418              ADJ_I2  419           
   ADJ_IHI  420             ADJ_J1  421              ADJ_J2  422           
   ADJ_JHI  423             ADJ_K1  424              ADJ_K2  425           
   ADJ_KHI  426             ADJ_L1  427              ADJ_L2  428           
   ADJ_LHI  429             ADJ_M1  430              ADJ_M2  431           
   ADJ_MHI  432             ADJ_N1  433              ADJ_N2  434           
   ADJ_NHI  435             ADJ_O1  436              ADJ_O2  437           
   ADJ_OHI  438             ADJ_P1  439              ADJ_P2  440           
   ADJ_PHI  441             BASADJ1  442             BASADJ2  443          
   BASADJHI  444            BASE1  445-446           BASE2  447-448        
   BASEHI  449-450          ADJOFR1  451-452         ADJOFR2  453-454      
   ADJOFRHI  455-456        ADJR_B1  457-458         ADJR_B2  459          
   ADJR_BHI  460-461        ADJR_C1  462             ADJR_C2  463          
   ADJR_CHI  464            ADJR_D1  465             ADJR_D2  466          
   ADJR_DHI  467            ADJR_E1  468             ADJR_E2  469          
   ADJR_EHI  470            ADJR_F1  471             ADJR_F2  472          
   ADJR_FHI  473            ADJR_G1  474             ADJR_G2  475          
   ADJR_GHI  476            ADJR_H1  477             ADJR_H2  478          
   ADJR_HHI  479            ADJR_I1  480             ADJR_I2  481          
   ADJR_IHI  482            ADJR_J1  483             ADJR_J2  484          
   ADJR_JHI  485            ADJR_K1  486             ADJR_K2  487          
   ADJR_KHI  488            ADJR_L1  489             ADJR_L2  490          
   ADJR_LHI  491            ADJR_M1  492             ADJR_M2  493          
   ADJR_MHI  494            ADJR_N1  495             ADJR_N2  496          
   ADJR_NHI  497            ADJR_O1  498             ADJR_O2  499          
   ADJR_OHI  500            ADJR_P1  501             ADJR_P2  502          
   ADJR_PHI  503            BASADR1  504             BASADR2  505          
   BASADRHI  506            BASER1  507-508          BASER2  509           
   BASERHI  510-511         ADJOFS1  512-513         ADJOFS2  514-515      
   ADJOFSHI  516-517        ADJS_B1  518-519         ADJS_B2  520          
   ADJS_BHI  521-522        ADJS_C1  523-524         ADJS_C2  525          
   ADJS_CHI  526-527        ADJS_D1  528-530         ADJS_D2  531          
   ADJS_DHI  532-534        ADJS_E1  535             ADJS_E2  536          
   ADJS_EHI  537            ADJS_F1  538             ADJS_F2  539          
   ADJS_FHI  540            ADJS_G1  541             ADJS_G2  542          
   ADJS_GHI  543            ADJS_H1  544             ADJS_H2  545          
   ADJS_HHI  546            ADJS_I1  547             ADJS_I2  548          
   ADJS_IHI  549            ADJS_J1  550             ADJS_J2  551          
   ADJS_JHI  552            ADJS_K1  553             ADJS_K2  554          
   ADJS_KHI  555            ADJS_L1  556             ADJS_L2  557          
   ADJS_LHI  558            ADJS_M1  559             ADJS_M2  560          
   ADJS_MHI  561            ADJS_N1  562             ADJS_N2  563          
   ADJS_NHI  564            ADJS_O1  565             ADJS_O2  566          
   ADJS_OHI  567            ADJS_P1  568             ADJS_P2  569          
   ADJS_PHI  570            BASADS1  571             BASADS2  572          
   BASADSHI  573            BASES1  574-575          BASES2  576-577       
   BASESHI  578-579         ADJOFC1  580-581         ADJOFC2  582          
   ADJOFCHI  583-584        ADJC_B1  585-586         ADJC_B2  587          
   ADJC_BHI  588-589        ADJC_C1  590             ADJC_C2  591          
   ADJC_CHI  592            ADJC_D1  593             ADJC_D2  594          
   ADJC_DHI  595            ADJC_E1  596             ADJC_E2  597          
   ADJC_EHI  598            ADJC_F1  599             ADJC_F2  600          
   ADJC_FHI  601            ADJC_G1  602             ADJC_G2  603          
   ADJC_GHI  604            ADJC_H1  605             ADJC_H2  606          
   ADJC_HHI  607            ADJC_I1  608             ADJC_I2  609          
   ADJC_IHI  610            ADJC_J1  611             ADJC_J2  612          
   ADJC_JHI  613            ADJC_K1  614             ADJC_K2  615          
   ADJC_KHI  616            ADJC_L1  617             ADJC_L2  618          
   ADJC_LHI  619            ADJC_M1  620             ADJC_M2  621          
   ADJC_MHI  622            ADJC_N1  623             ADJC_N2  624          
   ADJC_NHI  625            ADJC_O1  626             ADJC_O2  627          
   ADJC_OHI  628            ADJC_P1  629             ADJC_P2  630          
   ADJC_PHI  631            BASADC1  632             BASADC2  633          
   BASADCHI  634            BASEC1  635              BASEC2  636           
   BASECHI  637             ADJL_B1 $ 638            ADJL_B2 $ 639         
   ADJL_BHI $ 640           ADJL_C1 $ 641            ADJL_C2 $ 642         
   ADJL_CHI $ 643           ADJL_D1 $ 644            ADJL_D2 $ 645         
   ADJL_DHI $ 646           ADJL_E1 $ 647            ADJL_E2 $ 648         
   ADJL_EHI $ 649           ADJL_F1 $ 650            ADJL_F2 $ 651         
   ADJL_FHI $ 652           ADJL_G1 $ 653            ADJL_G2 $ 654         
   ADJL_GHI $ 655           ADJL_H1 $ 656            ADJL_H2 $ 657         
   ADJL_HHI $ 658           ADJL_I1 $ 659            ADJL_I2 $ 660         
   ADJL_IHI $ 661           ADJL_J1 $ 662            ADJL_J2 $ 663         
   ADJL_JHI $ 664           ADJL_K1 $ 665            ADJL_K2 $ 666-667     
   ADJL_KHI $ 668           ADJL_L1 $ 669            ADJL_L2 $ 670         
   ADJL_LHI $ 671           ADJL_M1 $ 672            ADJL_M2 $ 673         
   ADJL_MHI $ 674           ADJL_N1 $ 675            ADJL_N2 $ 676         
   ADJL_NHI $ 677           ADJL_O1 $ 678            ADJL_O2 $ 679         
   ADJL_OHI $ 680           ADJL_P1 $ 681-682        ADJL_P2 $ 683         
   ADJL_PHI $ 684-685       BASEL1 $ 686             BASEL2 $ 687          
   BASELHI $ 688            ADRL_B1 $ 689            ADRL_B2 $ 690         
   ADRL_BHI $ 691           ADRL_C1 $ 692            ADRL_C2 $ 693         
   ADRL_CHI $ 694           ADRL_D1 $ 695            ADRL_D2 $ 696         
   ADRL_DHI $ 697           ADRL_E1 $ 698            ADRL_E2 $ 699         
   ADRL_EHI $ 700           ADRL_F1 $ 701            ADRL_F2 $ 702         
   ADRL_FHI $ 703           ADRL_G1 $ 704            ADRL_G2 $ 705         
   ADRL_GHI $ 706           ADRL_H1 $ 707            ADRL_H2 $ 708         
   ADRL_HHI $ 709           ADRL_I1 $ 710            ADRL_I2 $ 711         
   ADRL_IHI $ 712           ADRL_J1 $ 713            ADRL_J2 $ 714         
   ADRL_JHI $ 715           ADRL_K1 $ 716            ADRL_K2 $ 717-718     
   ADRL_KHI $ 719           ADRL_L1 $ 720            ADRL_L2 $ 721         
   ADRL_LHI $ 722           ADRL_M1 $ 723            ADRL_M2 $ 724         
   ADRL_MHI $ 725           ADRL_N1 $ 726            ADRL_N2 $ 727         
   ADRL_NHI $ 728           ADRL_O1 $ 729            ADRL_O2 $ 730         
   ADRL_OHI $ 731           ADRL_P1 $ 732            ADRL_P2 $ 733         
   ADRL_PHI $ 734           BASERL1 $ 735            BASERL2 $ 736         
   BASERLHI $ 737           ADSL_B1 $ 738            ADSL_B2 $ 739         
   ADSL_BHI $ 740           ADSL_C1 $ 741            ADSL_C2 $ 742         
   ADSL_CHI $ 743           ADSL_D1 $ 744            ADSL_D2 $ 745         
   ADSL_DHI $ 746           ADSL_E1 $ 747            ADSL_E2 $ 748         
   ADSL_EHI $ 749           ADSL_F1 $ 750            ADSL_F2 $ 751         
   ADSL_FHI $ 752           ADSL_G1 $ 753            ADSL_G2 $ 754         
   ADSL_GHI $ 755           ADSL_H1 $ 756            ADSL_H2 $ 757         
   ADSL_HHI $ 758           ADSL_I1 $ 759            ADSL_I2 $ 760         
   ADSL_IHI $ 761           ADSL_J1 $ 762            ADSL_J2 $ 763         
   ADSL_JHI $ 764           ADSL_K1 $ 765            ADSL_K2 $ 766         
   ADSL_KHI $ 767           ADSL_L1 $ 768            ADSL_L2 $ 769         
   ADSL_LHI $ 770           ADSL_M1 $ 771            ADSL_M2 $ 772         
   ADSL_MHI $ 773           ADSL_N1 $ 774            ADSL_N2 $ 775         
   ADSL_NHI $ 776           ADSL_O1 $ 777            ADSL_O2 $ 778         
   ADSL_OHI $ 779           ADSL_P1 $ 780-781        ADSL_P2 $ 782         
   ADSL_PHI $ 783-784       BASESL1 $ 785            BASESL2 $ 786         
   BASESLHI $ 787           ADCL_B1 $ 788            ADCL_B2 $ 789         
   ADCL_BHI $ 790           ADCL_C1 $ 791            ADCL_C2 $ 792         
   ADCL_CHI $ 793           ADCL_D1 $ 794            ADCL_D2 $ 795         
   ADCL_DHI $ 796           ADCL_E1 $ 797            ADCL_E2 $ 798         
   ADCL_EHI $ 799           ADCL_F1 $ 800            ADCL_F2 $ 801         
   ADCL_FHI $ 802           ADCL_G1 $ 803            ADCL_G2 $ 804         
   ADCL_GHI $ 805           ADCL_H1 $ 806            ADCL_H2 $ 807         
   ADCL_HHI $ 808           ADCL_I1 $ 809            ADCL_I2 $ 810         
   ADCL_IHI $ 811           ADCL_J1 $ 812            ADCL_J2 $ 813         
   ADCL_JHI $ 814           ADCL_K1 $ 815            ADCL_K2 $ 816         
   ADCL_KHI $ 817           ADCL_L1 $ 818            ADCL_L2 $ 819         
   ADCL_LHI $ 820           ADCL_M1 $ 821            ADCL_M2 $ 822         
   ADCL_MHI $ 823           ADCL_N1 $ 824            ADCL_N2 $ 825         
   ADCL_NHI $ 826           ADCL_O1 $ 827            ADCL_O2 $ 828         
   ADCL_OHI $ 829           ADCL_P1 $ 830            ADCL_P2 $ 831         
   ADCL_PHI $ 832           BASECL1 $ 833            BASECL2 $ 834-836     
   BASECLHI $ 837           GDLINE1 $ 838-842        GDLINE2 $ 843-847     
   GDSTAT1 $ 848-852        GDSTAT2 $ 853-857        GDREF1 $ 858-862      
   GDREF2 $ 863-867         GDCROS1 $ 868-872        GDCROS2 $ 873         
   NOCOMP  874              GDLINEHI $ 875-879       GDSTATHI $ 880-884    
   GDREFHI $ 885-889        GDCROSHI $ 890-894       SMIN1  895-900        
   SMIN2  901-906           SMIN3  907-912           SMIN4  913-918        
   SMIN5  919-924           SMIN6  925-930           SMIN7  931-936        
   SMIN8  937-942           SMIN9  943-948           SMIN10  949-954       
   SMIN11  955-960          SMIN12  961-966          SMIN13  967-973       
   SMIN14  974-980          SMIN15  981-987          SMIN16  988-994       
   SMIN17  995-1001         SMIN18  1002-1008        SMIN19  1009          
   SMIN20  1010             SMIN21  1011             SMIN22  1012          
   SMIN23  1013             SMIN24  1014             SMIN25  1015          
   SMIN26  1016             SMIN27  1017             SMIN28  1018          
   SMIN29  1019             SMIN30  1020             SMIN31  1021          
   SMIN32  1022             SMIN33  1023             SMIN34  1024          
   SMIN35  1025             SMIN36  1026             SMIN37  1027          
   SMIN38  1028             SMIN39  1029             SMIN40  1030          
   SMAX1  1031-1039         SMAX2  1040-1047         SMAX3  1048-1055      
   SMAX4  1056-1063         SMAX5  1064-1071         SMAX6  1072-1079      
   SMAX7  1080-1087         SMAX8  1088-1095         SMAX9  1096-1103      
   SMAX10  1104-1111        SMAX11  1112-1119        SMAX12  1120-1127     
   SMAX13  1128-1135        SMAX14  1136-1143        SMAX15  1144-1151     
   SMAX16  1152-1159        SMAX17  1160-1166        SMAX18  1167-1173     
   SMAX19  1174-1179        SMAX20  1180-1185        SMAX21  1186-1191     
   SMAX22  1192-1197        SMAX23  1198-1203        SMAX24  1204-1209     
   SMAX25  1210-1215        SMAX26  1216-1221        SMAX27  1222-1227     
   SMAX28  1228-1233        SMAX29  1234-1239        SMAX30  1240-1245     
   SMAX31  1246-1251        SMAX32  1252-1257        SMAX33  1258-1263     
   SMAX34  1264-1269        SMAX35  1270-1275        SMAX36  1276-1281     
   SMAX37  1282-1287        SMAX38  1288-1293        SMAX39  1294-1299     
   SMAX40  1300-1305        STA1_1 $ 1306-1316       STA1_2 $ 1317-1326    
   STA1_3 $ 1327-1335       STA1_4 $ 1336-1343       STA1_5 $ 1344-1351    
   STA1_6 $ 1352-1359       STA1_7 $ 1360-1367       STA1_8 $ 1368-1374    
   STA1_9 $ 1375-1382       STA1_10 $ 1383-1389      STA1_11 $ 1390-1397   
   STA1_12 $ 1398-1404      STA1_13 $ 1405-1412      STA1_14 $ 1413-1419   
   STA1_15 $ 1420-1426      STA1_16 $ 1427-1432      STA1_17 $ 1433-1438   
   STA1_18 $ 1439-1444      STA1_19 $ 1445-1450      STA1_20 $ 1451-1456   
   STA1_21 $ 1457-1462      STA1_22 $ 1463-1468      STA1_23 $ 1469-1474   
   STA1_24 $ 1475-1482      STA1_25 $ 1483-1488      STA1_26 $ 1489-1494   
   STA1_27 $ 1495-1500      STA1_28 $ 1501-1506      STA1_29 $ 1507-1512   
   STA1_30 $ 1513-1518      STA1_31 $ 1519-1524      STA1_32 $ 1525-1530   
   STA1_33 $ 1531-1536      STA1_34 $ 1537-1542      STA1_35 $ 1543-1548   
   STA1_36 $ 1549-1554      STA1_37 $ 1555-1560      STA1_38 $ 1561-1566   
   STA1_39 $ 1567-1572      STA1_40 $ 1573-1578      STA2_1 $ 1579-1590    
   STA2_2 $ 1591-1598       STA2_3 $ 1599-1607       STA2_4 $ 1608-1614    
   STA2_5 $ 1615-1622       STA2_6 $ 1623-1629       STA2_7 $ 1630-1637    
   STA2_8 $ 1638-1645       STA2_9 $ 1646-1653       STA2_10 $ 1654-1661   
   STA2_11 $ 1662-1667      STA2_12 $ 1668-1673      STA2_13 $ 1674-1679   
   STA2_14 $ 1680-1685      STA2_15 $ 1686-1691      STA2_16 $ 1692-1697   
   STA2_17 $ 1698-1703      STA2_18 $ 1704-1706      STA2_19 $ 1707        
   STA2_20 $ 1708           STA2_21 $ 1709           STA2_22 $ 1710        
   STA2_23 $ 1711           STA2_24 $ 1712-1716      STA2_25 $ 1717        
   STA2_26 $ 1718           STA2_27 $ 1719           STA2_28 $ 1720        
   STA2_29 $ 1721           STA2_30 $ 1722           STA2_31 $ 1723        
   STA2_32 $ 1724           STA2_33 $ 1725           STA2_34 $ 1726        
   STA2_35 $ 1727           STA2_36 $ 1728           STA2_37 $ 1729        
   STA2_38 $ 1730           STA2_39 $ 1731           STA2_40 $ 1732        
   STA3_1 $ 1733-1741       STA3_2 $ 1742-1749       STA3_3 $ 1750-1756    
   STA3_4 $ 1757-1761       STA3_5 $ 1762-1769       STA3_6 $ 1770-1777    
   STA3_7 $ 1778-1782       STA3_8 $ 1783-1787       STA3_9 $ 1788         
   STA3_10 $ 1789           STA3_11 $ 1790           STA3_12 $ 1791        
   STA3_13 $ 1792           STA3_14 $ 1793           STA3_15 $ 1794        
   STA3_16 $ 1795           STA3_17 $ 1796           STA3_18 $ 1797        
   STA3_19 $ 1798           STA3_20 $ 1799           STA3_21 $ 1800        
   STA3_22 $ 1801           STA3_23 $ 1802           STA3_24 $ 1803        
   STA3_25 $ 1804           STA3_26 $ 1805           STA3_27 $ 1806        
   STA3_28 $ 1807           STA3_29 $ 1808           STA3_30 $ 1809        
   STA3_31 $ 1810           STA3_32 $ 1811           STA3_33 $ 1812        
   STA3_34 $ 1813           STA3_35 $ 1814           STA3_36 $ 1815        
   STA3_37 $ 1816           STA3_38 $ 1817           STA3_39 $ 1818        
   STA3_40 $ 1819           NWSTAT1 $ 1820-1830      NWSTAT2 $ 1831-1841   
   NWSTAT3 $ 1842-1853      NWSTAT4 $ 1854-1861      NWSTAT5 $ 1862-1868   
   NWSTAT6 $ 1869-1876      NWSTAT7 $ 1877-1884      NOUSTAT  1885         
   AMENDYR  1886-1889       BASEFINE  1890-1898      CH2APP  1899          
   CH8FINGD  1900           CMSRVORD  1901           COMPLYPR  1902        
   COSTASSM  1903           FINOFFST  1904-1909      FORFEITR  1910-1918   
   GLFINMAX  1919-1928      GLFINMIN  1929-1937      REMEDORD  1938        
   VICTNOTE  1939           BOOKERCD  1940-1941      QUARTER  1942         
   RETEXT1 $ 1943-1958      RETEXT2 $ 1959           RETEXT3 $ 1960        
   RETEXT4 $ 1961           RETEXT5 $ 1962           RETEXT6 $ 1963        
   RETEXT7 $ 1964           RETEXT8 $ 1965           RETEXT9 $ 1966        
   RETEXT10 $ 1967          REAS1  1968-1970         REAS2  1971-1973      
   REAS3  1974-1976         REAS4  1977-1979         REAS5  1980-1982      
   REAS6  1983              REAS7  1984              REAS8  1985           
   REAS9  1986              REAS10  1987             INPLEA1  1988         
   INPLEA2  1989            INPLEA3  1990            INPLEA4  1991         
   INPLEA5  1992            INPLEA6  1993            INPLEA7  1994         
   INPLEA8  1995            INPLEA9  1996            INPLEA10  1997        
   INPLEA11  1998           INPLEA12  1999           INNOPL1  2000         
   INNOPL2  2001            INNOPL3  2002            INNOPL4  2003         
   INNOPL5  2004            INNOPL6  2005            INNOPL7  2006         
   INNOPL8  2007            INNOPL9  2008            INNOPL10  2009        
   INNOPL11  2010           INNOPL12  2011           SENTYR  2012-2015     
   BOOKER2  2016            BOOKER3  2017            NEWCNVTN  2018        
   RESTCAT  2019            FINECAT  2020            SUSFNCAT  2021        
   LCAT1  2022              LCAT2  2023              LCATHI  2024          
   LCATS1  2025             LCATS2  2026             LCATSHI  2027         
   LCATR1  2028             LCATR2  2029             LCATRHI  2030         
   LCATC1  2031             LCATC2  2032             LCATCHI  2033         
 ;                       

LENGTH
   DISGORGE 4               CPIDN 6                  PSR 3                 
   JANDC 3                  PLEA 3                   REASONS 3             
   INDICT 3                 SENTRANS 3               WRKSHT 3              
   INCORPYR 4               INCORLOC 3               ORGTYPE 3             
   BUSCLAS 4                FTEMNUM 4                FTEMSIGN 3            
   SELFREP 3                HSMISCND 3               PRCRIME 3             
   PRCIVIL 3                OWNSTRCT 3               FINSTDS 3             
   FINSTDO 3                OFFENSE1 3               OFFENSE2 3            
   OFFENSE3 3               PRIMOFF 3                NOCOUNTS 3            
   SOURCES 3                OFFLVL 3                 DETBFINE 3            
   TOLERNCE 3               HISTORY 3                VIOLATE 3             
   OBSTRUCT 3               COMPLY 3                 ACCEPT 3              
   CCULPSCO 3               FCULPSCO 3               DISPOSIT 3            
   PROBATN 3                COFI 3                   PROBMON 3             
   ORDERCE 3                TYPEOTHS 3               CRIMPURP 3            
   CANTPAY 3                ADJOFL1 3                ADJOFL2 3             
   ADJOFLHI 3               ADJ_B1 3                 ADJ_B2 3              
   ADJ_BHI 3                ADJ_C1 3                 ADJ_C2 3              
   ADJ_CHI 3                ADJ_D1 3                 ADJ_D2 3              
   ADJ_DHI 3                ADJ_E1 3                 ADJ_E2 3              
   ADJ_EHI 3                ADJ_F1 3                 ADJ_F2 3              
   ADJ_FHI 3                ADJ_G1 3                 ADJ_G2 3              
   ADJ_GHI 3                ADJ_H1 3                 ADJ_H2 3              
   ADJ_HHI 3                ADJ_I1 3                 ADJ_I2 3              
   ADJ_IHI 3                ADJ_J1 3                 ADJ_J2 3              
   ADJ_JHI 3                ADJ_K1 3                 ADJ_K2 3              
   ADJ_KHI 3                ADJ_L1 3                 ADJ_L2 3              
   ADJ_LHI 3                ADJ_M1 3                 ADJ_M2 3              
   ADJ_MHI 3                ADJ_N1 3                 ADJ_N2 3              
   ADJ_NHI 3                ADJ_O1 3                 ADJ_O2 3              
   ADJ_OHI 3                ADJ_P1 3                 ADJ_P2 3              
   ADJ_PHI 3                BASADJ1 3                BASADJ2 3             
   BASADJHI 3               BASE1 3                  BASE2 3               
   BASEHI 3                 ADJOFR1 3                ADJOFR2 3             
   ADJOFRHI 3               ADJR_B1 3                ADJR_B2 3             
   ADJR_BHI 3               ADJR_C1 3                ADJR_C2 3             
   ADJR_CHI 3               ADJR_D1 3                ADJR_D2 3             
   ADJR_DHI 3               ADJR_E1 3                ADJR_E2 3             
   ADJR_EHI 3               ADJR_F1 3                ADJR_F2 3             
   ADJR_FHI 3               ADJR_G1 3                ADJR_G2 3             
   ADJR_GHI 3               ADJR_H1 3                ADJR_H2 3             
   ADJR_HHI 3               ADJR_I1 3                ADJR_I2 3             
   ADJR_IHI 3               ADJR_J1 3                ADJR_J2 3             
   ADJR_JHI 3               ADJR_K1 3                ADJR_K2 3             
   ADJR_KHI 3               ADJR_L1 3                ADJR_L2 3             
   ADJR_LHI 3               ADJR_M1 3                ADJR_M2 3             
   ADJR_MHI 3               ADJR_N1 3                ADJR_N2 3             
   ADJR_NHI 3               ADJR_O1 3                ADJR_O2 3             
   ADJR_OHI 3               ADJR_P1 3                ADJR_P2 3             
   ADJR_PHI 3               BASADR1 3                BASADR2 3             
   BASADRHI 3               BASER1 3                 BASER2 3              
   BASERHI 3                ADJOFS1 3                ADJOFS2 3             
   ADJOFSHI 3               ADJS_B1 3                ADJS_B2 3             
   ADJS_BHI 3               ADJS_C1 3                ADJS_C2 3             
   ADJS_CHI 3               ADJS_D1 3                ADJS_D2 3             
   ADJS_DHI 3               ADJS_E1 3                ADJS_E2 3             
   ADJS_EHI 3               ADJS_F1 3                ADJS_F2 3             
   ADJS_FHI 3               ADJS_G1 3                ADJS_G2 3             
   ADJS_GHI 3               ADJS_H1 3                ADJS_H2 3             
   ADJS_HHI 3               ADJS_I1 3                ADJS_I2 3             
   ADJS_IHI 3               ADJS_J1 3                ADJS_J2 3             
   ADJS_JHI 3               ADJS_K1 3                ADJS_K2 3             
   ADJS_KHI 3               ADJS_L1 3                ADJS_L2 3             
   ADJS_LHI 3               ADJS_M1 3                ADJS_M2 3             
   ADJS_MHI 3               ADJS_N1 3                ADJS_N2 3             
   ADJS_NHI 3               ADJS_O1 3                ADJS_O2 3             
   ADJS_OHI 3               ADJS_P1 3                ADJS_P2 3             
   ADJS_PHI 3               BASADS1 3                BASADS2 3             
   BASADSHI 3               BASES1 3                 BASES2 3              
   BASESHI 3                ADJOFC1 3                ADJOFC2 3             
   ADJOFCHI 3               ADJC_B1 3                ADJC_B2 3             
   ADJC_BHI 3               ADJC_C1 3                ADJC_C2 3             
   ADJC_CHI 3               ADJC_D1 3                ADJC_D2 3             
   ADJC_DHI 3               ADJC_E1 3                ADJC_E2 3             
   ADJC_EHI 3               ADJC_F1 3                ADJC_F2 3             
   ADJC_FHI 3               ADJC_G1 3                ADJC_G2 3             
   ADJC_GHI 3               ADJC_H1 3                ADJC_H2 3             
   ADJC_HHI 3               ADJC_I1 3                ADJC_I2 3             
   ADJC_IHI 3               ADJC_J1 3                ADJC_J2 3             
   ADJC_JHI 3               ADJC_K1 3                ADJC_K2 3             
   ADJC_KHI 3               ADJC_L1 3                ADJC_L2 3             
   ADJC_LHI 3               ADJC_M1 3                ADJC_M2 3             
   ADJC_MHI 3               ADJC_N1 3                ADJC_N2 3             
   ADJC_NHI 3               ADJC_O1 3                ADJC_O2 3             
   ADJC_OHI 3               ADJC_P1 3                ADJC_P2 3             
   ADJC_PHI 3               BASADC1 3                BASADC2 3             
   BASADCHI 3               BASEC1 3                 BASEC2 3              
   BASECHI 3                NOCOMP 3                 SMIN1 6               
   SMIN2 6                  SMIN3 6                  SMIN4 6               
   SMIN5 6                  SMIN6 6                  SMIN7 6               
   SMIN8 6                  SMIN9 6                  SMIN10 6              
   SMIN11 6                 SMIN12 6                 SMIN13 6              
   SMIN14 6                 SMIN15 6                 SMIN16 6              
   SMIN17 6                 SMIN18 6                 SMIN19 3              
   SMIN20 3                 SMIN21 3                 SMIN22 3              
   SMIN23 3                 SMIN24 3                 SMIN25 3              
   SMIN26 3                 SMIN27 3                 SMIN28 3              
   SMIN29 3                 SMIN30 3                 SMIN31 3              
   SMIN32 3                 SMIN33 3                 SMIN34 3              
   SMIN35 3                 SMIN36 3                 SMIN37 3              
   SMIN38 3                 SMIN39 3                 SMIN40 3              
   SMAX1 6                  SMAX2 6                  SMAX3 6               
   SMAX4 6                  SMAX5 6                  SMAX6 6               
   SMAX7 6                  SMAX8 6                  SMAX9 6               
   SMAX10 6                 SMAX11 6                 SMAX12 6              
   SMAX13 6                 SMAX14 6                 SMAX15 6              
   SMAX16 6                 SMAX17 6                 SMAX18 6              
   SMAX19 6                 SMAX20 6                 SMAX21 6              
   SMAX22 6                 SMAX23 6                 SMAX24 6              
   SMAX25 6                 SMAX26 6                 SMAX27 6              
   SMAX28 6                 SMAX29 6                 SMAX30 6              
   SMAX31 6                 SMAX32 6                 SMAX33 6              
   SMAX34 6                 SMAX35 6                 SMAX36 6              
   SMAX37 6                 SMAX38 6                 SMAX39 6              
   SMAX40 6                 NOUSTAT 3                AMENDYR 4             
   BASEFINE 6               CH2APP 3                 CH8FINGD 3            
   CMSRVORD 3               COMPLYPR 3               COSTASSM 3            
   FINOFFST 6               FORFEITR 6               GLFINMAX 6            
   GLFINMIN 6               REMEDORD 3               VICTNOTE 3            
   BOOKERCD 3               QUARTER 3                REAS1 4               
   REAS2 4                  REAS3 4                  REAS4 4               
   REAS5 4                  REAS6 3                  REAS7 3               
   REAS8 3                  REAS9 3                  REAS10 3              
   INPLEA1 3                INPLEA2 3                INPLEA3 3             
   INPLEA4 3                INPLEA5 3                INPLEA6 3             
   INPLEA7 3                INPLEA8 3                INPLEA9 3             
   INPLEA10 3               INPLEA11 3               INPLEA12 3            
   INNOPL1 3                INNOPL2 3                INNOPL3 3             
   INNOPL4 3                INNOPL5 3                INNOPL6 3             
   INNOPL7 3                INNOPL8 3                INNOPL9 3             
   INNOPL10 3               INNOPL11 3               INNOPL12 3            
   SENTYR 4                 BOOKER2 3                BOOKER3 3             
   NEWCNVTN 3               RESTCAT 3                FINECAT 3             
   SUSFNCAT 3               LCAT1 3                  LCAT2 3               
   LCATHI 3                 LCATS1 3                 LCATS2 3              
   LCATSHI 3                LCATR1 3                 LCATR2 3              
   LCATRHI 3                LCATC1 3                 LCATC2 3              
   LCATCHI 3 ;

         

RUN ;
